@@ -24,76 +24,87 @@
 #define DATA_FILE TESTS_DATA_DIR "/test-table.xml"
 
 static void
-atk_test_table_get_caption (gpointer fixture, gconstpointer user_data)
+atk_test_table_get_caption (TestAppFixture *fixture, gconstpointer user_data)
 {
-  AtspiAccessible *_obj = get_root_obj (DATA_FILE);
+  AtspiAccessible *_obj = fixture->root_obj;
   g_assert (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
   g_assert (child);
   AtspiTable *obj = atspi_accessible_get_table_iface (child);
   AtspiAccessible *acc = atspi_table_get_caption (obj, NULL);
-  g_assert (acc);
-  g_assert_cmpstr ("caption name", ==, atspi_accessible_get_name (acc, NULL));
+  check_name (acc, "caption name");
+  g_object_unref (acc);
+  g_object_unref (obj);
+  g_object_unref (child);
 }
 
 static void
-atk_test_table_get_summary (gpointer fixture, gconstpointer user_data)
+atk_test_table_get_summary (TestAppFixture *fixture, gconstpointer user_data)
 {
-  AtspiAccessible *_obj = get_root_obj (DATA_FILE);
+  AtspiAccessible *_obj = fixture->root_obj;
   g_assert (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
   g_assert (child);
   AtspiTable *obj = atspi_accessible_get_table_iface (child);
   AtspiAccessible *acc = atspi_table_get_summary (obj, NULL);
-  g_assert (acc);
-  g_assert_cmpstr ("table summary name", ==, atspi_accessible_get_name (acc, NULL));
+  check_name (acc, "table summary name");
+  g_object_unref (acc);
+  g_object_unref (obj);
+  g_object_unref (child);
 }
 
 static void
-atk_test_table_get_n_columns (gpointer fixture, gconstpointer user_data)
+atk_test_table_get_n_columns (TestAppFixture *fixture, gconstpointer user_data)
 {
-  AtspiAccessible *_obj = get_root_obj (DATA_FILE);
+  AtspiAccessible *_obj = fixture->root_obj;
   g_assert (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
   g_assert (child);
   AtspiTable *obj = atspi_accessible_get_table_iface (child);
   gint cnt = atspi_table_get_n_columns (obj, NULL);
   g_assert_cmpint (cnt, ==, 3);
+  g_object_unref (obj);
+  g_object_unref (child);
 }
 
 static void
-atk_test_table_get_n_rows (gpointer fixture, gconstpointer user_data)
+atk_test_table_get_n_rows (TestAppFixture *fixture, gconstpointer user_data)
 {
-  AtspiAccessible *_obj = get_root_obj (DATA_FILE);
+  AtspiAccessible *_obj = fixture->root_obj;
   g_assert (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
   g_assert (child);
   AtspiTable *obj = atspi_accessible_get_table_iface (child);
   gint cnt = atspi_table_get_n_rows (obj, NULL);
   g_assert_cmpint (cnt, ==, 4);
+  g_object_unref (obj);
+  g_object_unref (child);
 }
 
 static void
-atk_test_table_get_accessible_at (gpointer fixture, gconstpointer user_data)
+atk_test_table_get_accessible_at (TestAppFixture *fixture, gconstpointer user_data)
 {
-  AtspiAccessible *_obj = get_root_obj (DATA_FILE);
+  AtspiAccessible *_obj = fixture->root_obj;
   g_assert (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
   g_assert (child);
   AtspiTable *obj = atspi_accessible_get_table_iface (child);
   AtspiAccessible *acc = atspi_table_get_accessible_at (obj, 0, 0, NULL);
   g_assert (acc);
-  g_assert_cmpstr ("cell 0/0", ==, atspi_accessible_get_name (acc, NULL));
+  check_name (acc, "cell 0/0");
+  g_object_unref (acc);
 
   acc = atspi_table_get_accessible_at (obj, 3, 2, NULL);
-  g_assert (acc);
-  g_assert_cmpstr ("cell 2/3", ==, atspi_accessible_get_name (acc, NULL));
+  check_name (acc, "cell 2/3");
+  g_object_unref (acc);
+  g_object_unref (obj);
+  g_object_unref (child);
 }
 
 static void
-atk_test_table_get_index_at (gpointer fixture, gconstpointer user_data)
+atk_test_table_get_index_at (TestAppFixture *fixture, gconstpointer user_data)
 {
-  AtspiAccessible *_obj = get_root_obj (DATA_FILE);
+  AtspiAccessible *_obj = fixture->root_obj;
   g_assert (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
   g_assert (child);
@@ -107,12 +118,14 @@ atk_test_table_get_index_at (gpointer fixture, gconstpointer user_data)
 
   cnt = atspi_table_get_index_at (obj, 0, 1, NULL);
   g_assert_cmpint (cnt, ==, 1);
+  g_object_unref (obj);
+  g_object_unref (child);
 }
 
 static void
-atk_test_table_get_row_at_index (gpointer fixture, gconstpointer user_data)
+atk_test_table_get_row_at_index (TestAppFixture *fixture, gconstpointer user_data)
 {
-  AtspiAccessible *_obj = get_root_obj (DATA_FILE);
+  AtspiAccessible *_obj = fixture->root_obj;
   g_assert (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
   g_assert (child);
@@ -129,12 +142,14 @@ atk_test_table_get_row_at_index (gpointer fixture, gconstpointer user_data)
 
   cnt = atspi_table_get_row_at_index (obj, 11, NULL);
   g_assert_cmpint (cnt, ==, 3);
+  g_object_unref (obj);
+  g_object_unref (child);
 }
 
 static void
-atk_test_table_get_column_at_index (gpointer fixture, gconstpointer user_data)
+atk_test_table_get_column_at_index (TestAppFixture *fixture, gconstpointer user_data)
 {
-  AtspiAccessible *_obj = get_root_obj (DATA_FILE);
+  AtspiAccessible *_obj = fixture->root_obj;
   g_assert (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
   g_assert (child);
@@ -148,12 +163,14 @@ atk_test_table_get_column_at_index (gpointer fixture, gconstpointer user_data)
 
   cnt = atspi_table_get_column_at_index (obj, 5, NULL);
   g_assert_cmpint (cnt, ==, 2);
+  g_object_unref (obj);
+  g_object_unref (child);
 }
 
 static void
-atk_test_table_get_row_description (gpointer fixture, gconstpointer user_data)
+atk_test_table_get_row_description (TestAppFixture *fixture, gconstpointer user_data)
 {
-  AtspiAccessible *_obj = get_root_obj (DATA_FILE);
+  AtspiAccessible *_obj = fixture->root_obj;
   g_assert (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
   g_assert (child);
@@ -166,12 +183,14 @@ atk_test_table_get_row_description (gpointer fixture, gconstpointer user_data)
   g_assert (desc);
   g_assert_cmpstr (desc, ==, "third row");
   g_free (desc);
+  g_object_unref (obj);
+  g_object_unref (child);
 }
 
 static void
-atk_test_table_get_column_description (gpointer fixture, gconstpointer user_data)
+atk_test_table_get_column_description (TestAppFixture *fixture, gconstpointer user_data)
 {
-  AtspiAccessible *_obj = get_root_obj (DATA_FILE);
+  AtspiAccessible *_obj = fixture->root_obj;
   g_assert (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
   g_assert (child);
@@ -184,83 +203,95 @@ atk_test_table_get_column_description (gpointer fixture, gconstpointer user_data
   g_assert (desc);
   g_assert_cmpstr (desc, ==, "third column");
   g_free (desc);
+  g_object_unref (obj);
+  g_object_unref (child);
 }
 
 static void
-atk_test_table_get_row_extent_at (gpointer fixture, gconstpointer user_data)
+atk_test_table_get_row_extent_at (TestAppFixture *fixture, gconstpointer user_data)
 {
-  AtspiAccessible *_obj = get_root_obj (DATA_FILE);
+  AtspiAccessible *_obj = fixture->root_obj;
   g_assert (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
   g_assert (child);
   AtspiTable *obj = atspi_accessible_get_table_iface (child);
   gint cnt = atspi_table_get_row_extent_at (obj, 1, 1, NULL);
   g_assert_cmpint (cnt, ==, 1);
+  g_object_unref (obj);
+  g_object_unref (child);
 }
 
 static void
-atk_test_table_get_column_extent_at (gpointer fixture, gconstpointer user_data)
+atk_test_table_get_column_extent_at (TestAppFixture *fixture, gconstpointer user_data)
 {
-  AtspiAccessible *_obj = get_root_obj (DATA_FILE);
+  AtspiAccessible *_obj = fixture->root_obj;
   g_assert (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
   g_assert (child);
   AtspiTable *obj = atspi_accessible_get_table_iface (child);
   gint cnt = atspi_table_get_column_extent_at (obj, 1, 1, NULL);
   g_assert_cmpint (cnt, ==, 1);
+  g_object_unref (obj);
+  g_object_unref (child);
 }
 
 static void
-atk_test_table_get_row_header (gpointer fixture, gconstpointer user_data)
+atk_test_table_get_row_header (TestAppFixture *fixture, gconstpointer user_data)
 {
-  AtspiAccessible *_obj = get_root_obj (DATA_FILE);
+  AtspiAccessible *_obj = fixture->root_obj;
   g_assert (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
   g_assert (child);
   AtspiTable *obj = atspi_accessible_get_table_iface (child);
   AtspiAccessible *acc = atspi_table_get_row_header (obj, 0, NULL);
-  g_assert (acc);
-  g_assert_cmpstr ("row 1 header", ==, atspi_accessible_get_name (acc, NULL));
+  check_name (acc, "row 1 header");
+  g_object_unref (acc);
   acc = atspi_table_get_row_header (obj, 3, NULL);
-  g_assert (acc);
-  g_assert_cmpstr ("row 4 header", ==, atspi_accessible_get_name (acc, NULL));
+  check_name (acc, "row 4 header");
+  g_object_unref (acc);
+  g_object_unref (obj);
+  g_object_unref (child);
 }
 
 static void
-atk_test_table_get_column_header (gpointer fixture, gconstpointer user_data)
+atk_test_table_get_column_header (TestAppFixture *fixture, gconstpointer user_data)
 {
-  AtspiAccessible *_obj = get_root_obj (DATA_FILE);
+  AtspiAccessible *_obj = fixture->root_obj;
   g_assert (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
   g_assert (child);
   AtspiTable *obj = atspi_accessible_get_table_iface (child);
   AtspiAccessible *acc = atspi_table_get_column_header (obj, 0, NULL);
-  g_assert (acc);
-  g_assert_cmpstr ("column 1 header", ==, atspi_accessible_get_name (acc, NULL));
+  check_name (acc, "column 1 header");
+  g_object_unref (acc);
   acc = atspi_table_get_column_header (obj, 1, NULL);
-  g_assert (acc);
-  g_assert_cmpstr ("column 2 header", ==, atspi_accessible_get_name (acc, NULL));
+  check_name (acc, "column 2 header");
+  g_object_unref (acc);
   acc = atspi_table_get_column_header (obj, 2, NULL);
-  g_assert (acc);
-  g_assert_cmpstr ("column 3 header", ==, atspi_accessible_get_name (acc, NULL));
+  check_name (acc, "column 3 header");
+  g_object_unref (acc);
+  g_object_unref (obj);
+  g_object_unref (child);
 }
 
 static void
-atk_test_table_get_n_selected_rows (gpointer fixture, gconstpointer user_data)
+atk_test_table_get_n_selected_rows (TestAppFixture *fixture, gconstpointer user_data)
 {
-  AtspiAccessible *_obj = get_root_obj (DATA_FILE);
+  AtspiAccessible *_obj = fixture->root_obj;
   g_assert (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
   g_assert (child);
   AtspiTable *obj = atspi_accessible_get_table_iface (child);
   gint cnt = atspi_table_get_n_selected_rows (obj, NULL);
   g_assert_cmpint (cnt, ==, 2);
+  g_object_unref (obj);
+  g_object_unref (child);
 }
 
 static void
-atk_test_table_get_selected_rows (gpointer fixture, gconstpointer user_data)
+atk_test_table_get_selected_rows (TestAppFixture *fixture, gconstpointer user_data)
 {
-  AtspiAccessible *_obj = get_root_obj (DATA_FILE);
+  AtspiAccessible *_obj = fixture->root_obj;
   g_assert (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
   g_assert (child);
@@ -271,12 +302,14 @@ atk_test_table_get_selected_rows (gpointer fixture, gconstpointer user_data)
   g_assert_cmpint (g_array_index (array, gint, 0), ==, 0);
   g_assert_cmpint (g_array_index (array, gint, 1), ==, 2);
   g_array_free (array, TRUE);
+  g_object_unref (obj);
+  g_object_unref (child);
 }
 
 static void
-atk_test_table_get_selected_columns (gpointer fixture, gconstpointer user_data)
+atk_test_table_get_selected_columns (TestAppFixture *fixture, gconstpointer user_data)
 {
-  AtspiAccessible *_obj = get_root_obj (DATA_FILE);
+  AtspiAccessible *_obj = fixture->root_obj;
   g_assert (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
   g_assert (child);
@@ -287,12 +320,14 @@ atk_test_table_get_selected_columns (gpointer fixture, gconstpointer user_data)
   g_assert_cmpint (g_array_index (array, gint, 0), ==, 1);
 
   g_array_free (array, TRUE);
+  g_object_unref (obj);
+  g_object_unref (child);
 }
 
 static void
-atk_test_table_get_n_selected_columns (gpointer fixture, gconstpointer user_data)
+atk_test_table_get_n_selected_columns (TestAppFixture *fixture, gconstpointer user_data)
 {
-  AtspiAccessible *_obj = get_root_obj (DATA_FILE);
+  AtspiAccessible *_obj = fixture->root_obj;
   g_assert (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
   g_assert (child);
@@ -301,36 +336,43 @@ atk_test_table_get_n_selected_columns (gpointer fixture, gconstpointer user_data
   g_assert (obj);
   gint cnt = atspi_table_get_n_selected_columns (obj, NULL);
   g_assert_cmpint (cnt, ==, 1);
+  g_object_unref (obj);
+  g_object_unref (child);
 }
 
 static void
-atk_test_table_is_row_selected (gpointer fixture, gconstpointer user_data)
+atk_test_table_is_row_selected (TestAppFixture *fixture, gconstpointer user_data)
 {
-  AtspiAccessible *_obj = get_root_obj (DATA_FILE);
+  AtspiAccessible *_obj = fixture->root_obj;
   g_assert (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
   g_assert (child);
   AtspiTable *obj = atspi_accessible_get_table_iface (child);
+  g_assert (obj);
   g_assert_true (atspi_table_is_row_selected (obj, 0, NULL));
   g_assert_false (atspi_table_is_row_selected (obj, 1, NULL));
+  g_object_unref (obj);
+  g_object_unref (child);
 }
 
 static void
-atk_test_table_is_column_selected (gpointer fixture, gconstpointer user_data)
+atk_test_table_is_column_selected (TestAppFixture *fixture, gconstpointer user_data)
 {
-  AtspiAccessible *_obj = get_root_obj (DATA_FILE);
+  AtspiAccessible *_obj = fixture->root_obj;
   g_assert (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
   g_assert (child);
   AtspiTable *obj = atspi_accessible_get_table_iface (child);
   g_assert_true (atspi_table_is_column_selected (obj, 1, NULL));
   g_assert_false (atspi_table_is_column_selected (obj, 0, NULL));
+  g_object_unref (obj);
+  g_object_unref (child);
 }
 
 static void
-atk_test_table_add_row_selection (gpointer fixture, gconstpointer user_data)
+atk_test_table_add_row_selection (TestAppFixture *fixture, gconstpointer user_data)
 {
-  AtspiAccessible *_obj = get_root_obj (DATA_FILE);
+  AtspiAccessible *_obj = fixture->root_obj;
   g_assert (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
   g_assert (child);
@@ -338,12 +380,14 @@ atk_test_table_add_row_selection (gpointer fixture, gconstpointer user_data)
   g_assert_false (atspi_table_is_row_selected (obj, 1, NULL));
   g_assert_true (atspi_table_add_row_selection (obj, 1, NULL));
   g_assert_true (atspi_table_is_row_selected (obj, 1, NULL));
+  g_object_unref (obj);
+  g_object_unref (child);
 }
 
 static void
-atk_test_table_add_column_selection (gpointer fixture, gconstpointer user_data)
+atk_test_table_add_column_selection (TestAppFixture *fixture, gconstpointer user_data)
 {
-  AtspiAccessible *_obj = get_root_obj (DATA_FILE);
+  AtspiAccessible *_obj = fixture->root_obj;
   g_assert (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
   g_assert (child);
@@ -351,12 +395,14 @@ atk_test_table_add_column_selection (gpointer fixture, gconstpointer user_data)
   g_assert_false (atspi_table_is_column_selected (obj, 2, NULL));
   g_assert_true (atspi_table_add_column_selection (obj, 2, NULL));
   g_assert_true (atspi_table_is_column_selected (obj, 2, NULL));
+  g_object_unref (obj);
+  g_object_unref (child);
 }
 
 static void
-atk_test_table_remove_row_selection (gpointer fixture, gconstpointer user_data)
+atk_test_table_remove_row_selection (TestAppFixture *fixture, gconstpointer user_data)
 {
-  AtspiAccessible *_obj = get_root_obj (DATA_FILE);
+  AtspiAccessible *_obj = fixture->root_obj;
   g_assert (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
   g_assert (child);
@@ -364,12 +410,14 @@ atk_test_table_remove_row_selection (gpointer fixture, gconstpointer user_data)
   g_assert_true (atspi_table_is_row_selected (obj, 2, NULL));
   g_assert_true (atspi_table_remove_row_selection (obj, 2, NULL));
   g_assert_false (atspi_table_is_row_selected (obj, 2, NULL));
+  g_object_unref (obj);
+  g_object_unref (child);
 }
 
 static void
-atk_test_table_remove_column_selection (gpointer fixture, gconstpointer user_data)
+atk_test_table_remove_column_selection (TestAppFixture *fixture, gconstpointer user_data)
 {
-  AtspiAccessible *_obj = get_root_obj (DATA_FILE);
+  AtspiAccessible *_obj = fixture->root_obj;
   g_assert (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
   g_assert (child);
@@ -377,12 +425,14 @@ atk_test_table_remove_column_selection (gpointer fixture, gconstpointer user_dat
   g_assert_true (atspi_table_is_column_selected (obj, 1, NULL));
   g_assert_true (atspi_table_remove_column_selection (obj, 1, NULL));
   g_assert_false (atspi_table_is_column_selected (obj, 1, NULL));
+  g_object_unref (obj);
+  g_object_unref (child);
 }
 
 static void
-atk_test_table_get_row_column_extents_at_index (gpointer fixture, gconstpointer user_data)
+atk_test_table_get_row_column_extents_at_index (TestAppFixture *fixture, gconstpointer user_data)
 {
-  AtspiAccessible *_obj = get_root_obj (DATA_FILE);
+  AtspiAccessible *_obj = fixture->root_obj;
   g_assert (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
   g_assert (child);
@@ -399,79 +449,77 @@ atk_test_table_get_row_column_extents_at_index (gpointer fixture, gconstpointer
   g_assert_cmpint (row_ext, ==, 2);
   g_assert_cmpint (col_ext, ==, 1);
   g_assert_false (is_selected);
+  g_object_unref (obj);
+  g_object_unref (child);
 }
 
 static void
-atk_test_table_is_selected (gpointer fixture, gconstpointer user_data)
+atk_test_table_is_selected (TestAppFixture *fixture, gconstpointer user_data)
 {
-  AtspiAccessible *_obj = get_root_obj (DATA_FILE);
+  AtspiAccessible *_obj = fixture->root_obj;
   g_assert (_obj);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (_obj, 0, NULL);
   g_assert (child);
   AtspiTable *obj = atspi_accessible_get_table_iface (child);
   g_assert_true (atspi_table_is_selected (obj, 0, 2, NULL));
   g_assert_false (atspi_table_is_selected (obj, 1, 0, NULL));
-}
-
-static void
-teardown_table_test (gpointer fixture, gconstpointer user_data)
-{
-  terminate_app ();
+  g_object_unref (obj);
+  g_object_unref (child);
 }
 
 void
 atk_test_table (void)
 {
-  g_test_add_vtable (ATK_TEST_PATH_TABLE "/atk_test_table_get_caption",
-                     0, NULL, NULL, atk_test_table_get_caption, teardown_table_test);
-  g_test_add_vtable (ATK_TEST_PATH_TABLE "/atk_test_table_get_summary",
-                     0, NULL, NULL, atk_test_table_get_summary, teardown_table_test);
-  g_test_add_vtable (ATK_TEST_PATH_TABLE "/atk_test_table_get_n_columns",
-                     0, NULL, NULL, atk_test_table_get_n_columns, teardown_table_test);
-  g_test_add_vtable (ATK_TEST_PATH_TABLE "/atk_test_table_get_n_rows",
-                     0, NULL, NULL, atk_test_table_get_n_rows, teardown_table_test);
-  g_test_add_vtable (ATK_TEST_PATH_TABLE "/atk_test_table_get_accessible_at",
-                     0, NULL, NULL, atk_test_table_get_accessible_at, teardown_table_test);
-  g_test_add_vtable (ATK_TEST_PATH_TABLE "/atk_test_table_get_index_at",
-                     0, NULL, NULL, atk_test_table_get_index_at, teardown_table_test);
-  g_test_add_vtable (ATK_TEST_PATH_TABLE "/atk_test_table_get_row_at_index",
-                     0, NULL, NULL, atk_test_table_get_row_at_index, teardown_table_test);
-  g_test_add_vtable (ATK_TEST_PATH_TABLE "/atk_test_table_get_column_at_index",
-                     0, NULL, NULL, atk_test_table_get_column_at_index, teardown_table_test);
-  g_test_add_vtable (ATK_TEST_PATH_TABLE "/atk_test_table_get_row_description",
-                     0, NULL, NULL, atk_test_table_get_row_description, teardown_table_test);
-  g_test_add_vtable (ATK_TEST_PATH_TABLE "/atk_test_table_get_column_description",
-                     0, NULL, NULL, atk_test_table_get_column_description, teardown_table_test);
-  g_test_add_vtable (ATK_TEST_PATH_TABLE "/atk_test_table_get_row_extent_at",
-                     0, NULL, NULL, atk_test_table_get_row_extent_at, teardown_table_test);
-  g_test_add_vtable (ATK_TEST_PATH_TABLE "/atk_test_table_get_column_extent_at",
-                     0, NULL, NULL, atk_test_table_get_column_extent_at, teardown_table_test);
-  g_test_add_vtable (ATK_TEST_PATH_TABLE "/atk_test_table_get_row_header",
-                     0, NULL, NULL, atk_test_table_get_row_header, teardown_table_test);
-  g_test_add_vtable (ATK_TEST_PATH_TABLE "/atk_test_table_get_column_header",
-                     0, NULL, NULL, atk_test_table_get_column_header, teardown_table_test);
-  g_test_add_vtable (ATK_TEST_PATH_TABLE "/atk_test_table_get_n_selected_rows",
-                     0, NULL, NULL, atk_test_table_get_n_selected_rows, teardown_table_test);
-  g_test_add_vtable (ATK_TEST_PATH_TABLE "/atk_test_table_get_selected_rows",
-                     0, NULL, NULL, atk_test_table_get_selected_rows, teardown_table_test);
-  g_test_add_vtable (ATK_TEST_PATH_TABLE "/atk_test_table_get_selected_columns",
-                     0, NULL, NULL, atk_test_table_get_selected_columns, teardown_table_test);
-  g_test_add_vtable (ATK_TEST_PATH_TABLE "/atk_test_table_get_n_selected_columns",
-                     0, NULL, NULL, atk_test_table_get_n_selected_columns, teardown_table_test);
-  g_test_add_vtable (ATK_TEST_PATH_TABLE "/atk_test_table_is_row_selected",
-                     0, NULL, NULL, atk_test_table_is_row_selected, teardown_table_test);
-  g_test_add_vtable (ATK_TEST_PATH_TABLE "/atk_test_table_is_column_selected",
-                     0, NULL, NULL, atk_test_table_is_column_selected, teardown_table_test);
-  g_test_add_vtable (ATK_TEST_PATH_TABLE "/atk_test_table_add_row_selection",
-                     0, NULL, NULL, atk_test_table_add_row_selection, teardown_table_test);
-  g_test_add_vtable (ATK_TEST_PATH_TABLE "/atk_test_table_add_column_selection",
-                     0, NULL, NULL, atk_test_table_add_column_selection, teardown_table_test);
-  g_test_add_vtable (ATK_TEST_PATH_TABLE "/atk_test_table_remove_row_selection",
-                     0, NULL, NULL, atk_test_table_remove_row_selection, teardown_table_test);
-  g_test_add_vtable (ATK_TEST_PATH_TABLE "/atk_test_table_remove_column_selection",
-                     0, NULL, NULL, atk_test_table_remove_column_selection, teardown_table_test);
-  g_test_add_vtable (ATK_TEST_PATH_TABLE "/atk_test_table_get_row_column_extents_at_index",
-                     0, NULL, NULL, atk_test_table_get_row_column_extents_at_index, teardown_table_test);
-  g_test_add_vtable (ATK_TEST_PATH_TABLE "/atk_test_table_is_selected",
-                     0, NULL, NULL, atk_test_table_is_selected, teardown_table_test);
+  g_test_add ("/table/atk_test_table_get_caption",
+              TestAppFixture, DATA_FILE, fixture_setup, atk_test_table_get_caption, fixture_teardown);
+  g_test_add ("/table/atk_test_table_get_summary",
+              TestAppFixture, DATA_FILE, fixture_setup, atk_test_table_get_summary, fixture_teardown);
+  g_test_add ("/table/atk_test_table_get_n_columns",
+              TestAppFixture, DATA_FILE, fixture_setup, atk_test_table_get_n_columns, fixture_teardown);
+  g_test_add ("/table/atk_test_table_get_n_rows",
+              TestAppFixture, DATA_FILE, fixture_setup, atk_test_table_get_n_rows, fixture_teardown);
+  g_test_add ("/table/atk_test_table_get_accessible_at",
+              TestAppFixture, DATA_FILE, fixture_setup, atk_test_table_get_accessible_at, fixture_teardown);
+  g_test_add ("/table/atk_test_table_get_index_at",
+              TestAppFixture, DATA_FILE, fixture_setup, atk_test_table_get_index_at, fixture_teardown);
+  g_test_add ("/table/atk_test_table_get_row_at_index",
+              TestAppFixture, DATA_FILE, fixture_setup, atk_test_table_get_row_at_index, fixture_teardown);
+  g_test_add ("/table/atk_test_table_get_column_at_index",
+              TestAppFixture, DATA_FILE, fixture_setup, atk_test_table_get_column_at_index, fixture_teardown);
+  g_test_add ("/table/atk_test_table_get_row_description",
+              TestAppFixture, DATA_FILE, fixture_setup, atk_test_table_get_row_description, fixture_teardown);
+  g_test_add ("/table/atk_test_table_get_column_description",
+              TestAppFixture, DATA_FILE, fixture_setup, atk_test_table_get_column_description, fixture_teardown);
+  g_test_add ("/table/atk_test_table_get_row_extent_at",
+              TestAppFixture, DATA_FILE, fixture_setup, atk_test_table_get_row_extent_at, fixture_teardown);
+  g_test_add ("/table/atk_test_table_get_column_extent_at",
+              TestAppFixture, DATA_FILE, fixture_setup, atk_test_table_get_column_extent_at, fixture_teardown);
+  g_test_add ("/table/atk_test_table_get_row_header",
+              TestAppFixture, DATA_FILE, fixture_setup, atk_test_table_get_row_header, fixture_teardown);
+  g_test_add ("/table/atk_test_table_get_column_header",
+              TestAppFixture, DATA_FILE, fixture_setup, atk_test_table_get_column_header, fixture_teardown);
+  g_test_add ("/table/atk_test_table_get_n_selected_rows",
+              TestAppFixture, DATA_FILE, fixture_setup, atk_test_table_get_n_selected_rows, fixture_teardown);
+  g_test_add ("/table/atk_test_table_get_selected_rows",
+              TestAppFixture, DATA_FILE, fixture_setup, atk_test_table_get_selected_rows, fixture_teardown);
+  g_test_add ("/table/atk_test_table_get_selected_columns",
+              TestAppFixture, DATA_FILE, fixture_setup, atk_test_table_get_selected_columns, fixture_teardown);
+  g_test_add ("/table/atk_test_table_get_n_selected_columns",
+              TestAppFixture, DATA_FILE, fixture_setup, atk_test_table_get_n_selected_columns, fixture_teardown);
+  g_test_add ("/table/atk_test_table_is_row_selected",
+              TestAppFixture, DATA_FILE, fixture_setup, atk_test_table_is_row_selected, fixture_teardown);
+  g_test_add ("/table/atk_test_table_is_column_selected",
+              TestAppFixture, DATA_FILE, fixture_setup, atk_test_table_is_column_selected, fixture_teardown);
+  g_test_add ("/table/atk_test_table_add_row_selection",
+              TestAppFixture, DATA_FILE, fixture_setup, atk_test_table_add_row_selection, fixture_teardown);
+  g_test_add ("/table/atk_test_table_add_column_selection",
+              TestAppFixture, DATA_FILE, fixture_setup, atk_test_table_add_column_selection, fixture_teardown);
+  g_test_add ("/table/atk_test_table_remove_row_selection",
+              TestAppFixture, DATA_FILE, fixture_setup, atk_test_table_remove_row_selection, fixture_teardown);
+  g_test_add ("/table/atk_test_table_remove_column_selection",
+              TestAppFixture, DATA_FILE, fixture_setup, atk_test_table_remove_column_selection, fixture_teardown);
+  g_test_add ("/table/atk_test_table_get_row_column_extents_at_index",
+              TestAppFixture, DATA_FILE, fixture_setup, atk_test_table_get_row_column_extents_at_index, fixture_teardown);
+  g_test_add ("/table/atk_test_table_is_selected",
+              TestAppFixture, DATA_FILE, fixture_setup, atk_test_table_is_selected, fixture_teardown);
 }
